==> nextcloud-27.1.11p0.tgz: nextcloud/apps/files_reminders/l10n/hu.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Fájl emlékeztetők",
    "Reminder for {name}" : "Emlékeztető a következőhöz: {name}",
    "View file" : "Fájl megtekintése",
    "View folder" : "Mappa megtekintése",
    "Set file reminders" : "Fájl emlékeztetők beállítása",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Fájl emlékeztetők**\n\nFájl emlékeztetők beállítása.",
    "Please choose a valid date & time" : "Adjon meg egy érvényes dátumot és időt",
    "Cancel" : "Mégse",
    "Clear reminder" : "Emlékeztető törlése",
    "Set reminder" : "Emlékeztető beállítása",
    "Set reminder at custom date & time" : "Emlékeztető beállítása tetszőleges időpontra",
    "Reminder set for \"{fileName}\"" : "Emlékeztető beállítva a következőhöz: {name}",
    "Failed to set reminder" : "Nem sikerült beállítani az emlékeztetőt",
    "Failed to clear reminder" : "Nem sikerült törölni az emlékeztetőt",
    "Set custom reminder" : "Egyéni emlékeztető beállítása",
    "Later today" : "Mai nap később",
    "Set reminder for later today" : "Emlékeztető beállítása a mai napon későbbre",
    "Tomorrow" : "Holnap",
    "Set reminder for tomorrow" : "Emlékeztető beállítása holnapra",
    "This weekend" : "Ezen a héten",
    "Set reminder for this weekend" : "Emlékeztető beállítása erre a hétvégére",
    "Next week" : "Következő hét",
    "Set reminder for next week" : "Emlékeztető beállítása a következő hétre",
    "Back" : "Vissza",
    "Reminder cleared" : "Emlékeztető törölve",
    "Failed to load reminder" : "Nem sikerült betölteni az emlékeztetőt"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.14.tgz: nextcloud/apps/files_reminders/l10n/hu.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Fájl emlékeztetők",
    "Reminder for {name}" : "Emlékeztető a következőhöz: {name}",
    "View file" : "Fájl megtekintése",
    "View folder" : "Mappa megtekintése",
    "Set file reminders" : "Fájl emlékeztetők beállítása",
    "We will remind you of this file" : "Emlékeztetni fogjuk Önt erre a fájlra",
    "Please choose a valid date & time" : "Adjon meg egy érvényes dátumot és időt",
    "Cancel" : "Mégse",
    "Clear reminder" : "Emlékeztető törlése",
    "Set reminder" : "Emlékeztető beállítása",
    "Set reminder for \"{fileName}\"" : "Emlékeztető beállítása a következőhöz: „{fileName}”",
    "Set reminder at custom date & time" : "Emlékeztető beállítása tetszőleges időpontra",
    "Reminder set for \"{fileName}\"" : "Emlékeztető beállítva a következőhöz: {fileName}",
    "Failed to set reminder" : "Nem sikerült beállítani az emlékeztetőt",
    "Reminder cleared for \"{fileName}\"" : "Emlékeztető törlése a következőhöz: „{fileName}”",
    "Failed to clear reminder" : "Nem sikerült törölni az emlékeztetőt",
    "Reminder set" : "Emlékeztető beállítása",
    "Set custom reminder" : "Egyéni emlékeztető beállítása",
    "Later today" : "Mai nap később",
    "Set reminder for later today" : "Emlékeztető beállítása a mai napon későbbre",
    "Tomorrow" : "Holnap",
    "Set reminder for tomorrow" : "Emlékeztető beállítása holnapra",
    "This weekend" : "Ezen a héten",
    "Set reminder for this weekend" : "Emlékeztető beállítása erre a hétvégére",
    "Next week" : "Következő hét",
    "Set reminder for next week" : "Emlékeztető beállítása a következő hétre",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Fájl emlékeztetők**\n\nFájl emlékeztetők beállítása."
},
"nplurals=2; plural=(n != 1);");
